pub struct Client { /* private fields */ }Expand description
Client for AWS Artifact
Client for invoking operations on AWS Artifact. Each operation on AWS Artifact is a method on this
this struct. .send() MUST be invoked on the generated operations to dispatch the request to the service.
Constructing a Client
A Config is required to construct a client. For most use cases, the aws-config
crate should be used to automatically resolve this config using
aws_config::load_from_env(), since this will resolve an SdkConfig which can be shared
across multiple different AWS SDK clients. This config resolution process can be customized
by calling aws_config::from_env() instead, which returns a ConfigLoader that uses
the builder pattern to customize the default config.
In the simplest case, creating a client looks as follows:
let config = aws_config::load_from_env().await;
let client = aws_sdk_artifact::Client::new(&config);Occasionally, SDKs may have additional service-specific values that can be set on the Config that
is absent from SdkConfig, or slightly different settings for a specific client may be desired.
The Builder struct implements From<&SdkConfig>, so setting these specific settings can be
done as follows:
let sdk_config = ::aws_config::load_from_env().await;
let config = aws_sdk_artifact::config::Builder::from(&sdk_config)
.some_service_specific_setting("value")
.build();See the aws-config docs and Config for more information on customizing configuration.
Note: Client construction is expensive due to connection thread pool initialization, and should be done once at application start-up.
Using the Client
A client has a function for every operation that can be performed by the service.
For example, the CreateComplianceInquiry operation has
a Client::create_compliance_inquiry, function which returns a builder for that operation.
The fluent builder ultimately has a send() function that returns an async future that
returns a result, as illustrated below:
let result = client.create_compliance_inquiry()
.name("example")
.send()
.await;The underlying HTTP requests that get made by this can be modified with the customize_operation
function on the fluent builder. See the customize module for more
information.
Implementations
Sourceimpl Client
impl Client
Sourcepub fn create_compliance_inquiry(&self) -> CreateComplianceInquiryFluentBuilder
pub fn create_compliance_inquiry(&self) -> CreateComplianceInquiryFluentBuilder
Constructs a fluent builder for the CreateComplianceInquiry operation.
- The fluent builder is configurable:
name(impl Into<String>)/set_name(Option<String>):
required: trueTitle of the inquiry.
inquiry_content(InquiryContent)/set_inquiry_content(Option<InquiryContent>):
required: trueContent for creating a compliance inquiry - either a single query or file content.
client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseIdempotency token for the request.
support_mode(InquirySupportMode)/set_support_mode(Option<InquirySupportMode>):
required: falseSupport mode for inquiry processing. Only supported for file upload mode. Defaults to AI_ONLY if not specified.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: falseTags to associate with the compliance inquiry resource.
- On success, responds with
CreateComplianceInquiryOutputwith field(s):compliance_inquiry_summary(Option<InquirySummary>):Summary information about the created compliance inquiry.
tags(Option<HashMap::<String, String>>):Tags associated with the compliance inquiry resource.
- On failure, responds with
SdkError<CreateComplianceInquiryError>
Sourceimpl Client
impl Client
Sourcepub fn export_compliance_inquiry(&self) -> ExportComplianceInquiryFluentBuilder
pub fn export_compliance_inquiry(&self) -> ExportComplianceInquiryFluentBuilder
Constructs a fluent builder for the ExportComplianceInquiry operation.
- The fluent builder is configurable:
compliance_inquiry_id(impl Into<String>)/set_compliance_inquiry_id(Option<String>):
required: trueUnique resource ID for the compliance inquiry.
query_identifiers(i32)/set_query_identifiers(Option<Vec::<i32>>):
required: falseList of query identifiers to include in the export.
include_citations(bool)/set_include_citations(Option<bool>):
required: falseWhen true, include citations in the exported document.
- On success, responds with
ExportComplianceInquiryOutputwith field(s):document_presigned_url(Option<String>):Presigned S3 URL to access the exported compliance inquiry report.
tags(Option<HashMap::<String, String>>):Tags associated with the compliance inquiry resource.
- On failure, responds with
SdkError<ExportComplianceInquiryError>
Sourceimpl Client
impl Client
Sourcepub fn get_account_settings(&self) -> GetAccountSettingsFluentBuilder
pub fn get_account_settings(&self) -> GetAccountSettingsFluentBuilder
Constructs a fluent builder for the GetAccountSettings operation.
- The fluent builder takes no input, just
sendit. - On success, responds with
GetAccountSettingsOutputwith field(s):account_settings(Option<AccountSettings>):Account settings for the customer.
- On failure, responds with
SdkError<GetAccountSettingsError>
Sourceimpl Client
impl Client
Sourcepub fn get_compliance_inquiry_metadata(
&self,
) -> GetComplianceInquiryMetadataFluentBuilder
pub fn get_compliance_inquiry_metadata( &self, ) -> GetComplianceInquiryMetadataFluentBuilder
Constructs a fluent builder for the GetComplianceInquiryMetadata operation.
- The fluent builder is configurable:
compliance_inquiry_id(impl Into<String>)/set_compliance_inquiry_id(Option<String>):
required: trueUnique resource ID for the compliance inquiry.
- On success, responds with
GetComplianceInquiryMetadataOutputwith field(s):compliance_inquiry_detail(Option<InquiryDetail>):Detailed information about the compliance inquiry.
tags(Option<HashMap::<String, String>>):Tags associated with the compliance inquiry resource.
- On failure, responds with
SdkError<GetComplianceInquiryMetadataError>
Sourceimpl Client
impl Client
Sourcepub fn get_report(&self) -> GetReportFluentBuilder
pub fn get_report(&self) -> GetReportFluentBuilder
Constructs a fluent builder for the GetReport operation.
- The fluent builder is configurable:
report_id(impl Into<String>)/set_report_id(Option<String>):
required: trueUnique resource ID for the report resource.
report_version(i64)/set_report_version(Option<i64>):
required: falseVersion for the report resource.
term_token(impl Into<String>)/set_term_token(Option<String>):
required: trueUnique download token provided by GetTermForReport API.
- On success, responds with
GetReportOutputwith field(s):document_presigned_url(Option<String>):Presigned S3 url to access the report content.
- On failure, responds with
SdkError<GetReportError>
Sourceimpl Client
impl Client
Sourcepub fn get_report_metadata(&self) -> GetReportMetadataFluentBuilder
pub fn get_report_metadata(&self) -> GetReportMetadataFluentBuilder
Constructs a fluent builder for the GetReportMetadata operation.
- The fluent builder is configurable:
report_id(impl Into<String>)/set_report_id(Option<String>):
required: trueUnique resource ID for the report resource.
report_version(i64)/set_report_version(Option<i64>):
required: falseVersion for the report resource.
- On success, responds with
GetReportMetadataOutputwith field(s):report_details(Option<ReportDetail>):Report resource detail.
- On failure, responds with
SdkError<GetReportMetadataError>
Sourceimpl Client
impl Client
Sourcepub fn get_term_for_report(&self) -> GetTermForReportFluentBuilder
pub fn get_term_for_report(&self) -> GetTermForReportFluentBuilder
Constructs a fluent builder for the GetTermForReport operation.
- The fluent builder is configurable:
report_id(impl Into<String>)/set_report_id(Option<String>):
required: trueUnique resource ID for the report resource.
report_version(i64)/set_report_version(Option<i64>):
required: falseVersion for the report resource.
- On success, responds with
GetTermForReportOutputwith field(s):document_presigned_url(Option<String>):Presigned S3 url to access the term content.
term_token(Option<String>):Unique token representing this request event.
- On failure, responds with
SdkError<GetTermForReportError>
Sourceimpl Client
impl Client
Sourcepub fn list_compliance_inquiries(&self) -> ListComplianceInquiriesFluentBuilder
pub fn list_compliance_inquiries(&self) -> ListComplianceInquiriesFluentBuilder
Constructs a fluent builder for the ListComplianceInquiries operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseMaximum number of resources to return in the paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falsePagination token to request the next page of resources.
- On success, responds with
ListComplianceInquiriesOutputwith field(s):compliance_inquiries(Option<Vec::<InquirySummary>>):List of compliance inquiry resources.
next_token(Option<String>):Pagination token to request the next page of resources.
- On failure, responds with
SdkError<ListComplianceInquiriesError>
Sourceimpl Client
impl Client
Sourcepub fn list_compliance_inquiry_queries(
&self,
) -> ListComplianceInquiryQueriesFluentBuilder
pub fn list_compliance_inquiry_queries( &self, ) -> ListComplianceInquiryQueriesFluentBuilder
Constructs a fluent builder for the ListComplianceInquiryQueries operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
compliance_inquiry_id(impl Into<String>)/set_compliance_inquiry_id(Option<String>):
required: trueUnique resource ID for the compliance inquiry.
max_results(i32)/set_max_results(Option<i32>):
required: falseMaximum number of resources to return in the paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falsePagination token to request the next page of resources.
- On success, responds with
ListComplianceInquiryQueriesOutputwith field(s):queries(Option<Vec::<QuerySummary>>):List of compliance query summaries.
next_token(Option<String>):Pagination token to request the next page of resources.
- On failure, responds with
SdkError<ListComplianceInquiryQueriesError>
Sourceimpl Client
impl Client
Sourcepub fn list_customer_agreements(&self) -> ListCustomerAgreementsFluentBuilder
pub fn list_customer_agreements(&self) -> ListCustomerAgreementsFluentBuilder
Constructs a fluent builder for the ListCustomerAgreements operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseMaximum number of resources to return in the paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falsePagination token to request the next page of resources.
- On success, responds with
ListCustomerAgreementsOutputwith field(s):customer_agreements(Vec::<CustomerAgreementSummary>):List of customer-agreement resources.
next_token(Option<String>):Pagination token to request the next page of resources.
- On failure, responds with
SdkError<ListCustomerAgreementsError>
Sourceimpl Client
impl Client
Sourcepub fn list_report_versions(&self) -> ListReportVersionsFluentBuilder
pub fn list_report_versions(&self) -> ListReportVersionsFluentBuilder
Constructs a fluent builder for the ListReportVersions operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
report_id(impl Into<String>)/set_report_id(Option<String>):
required: trueUnique resource ID for the report resource.
max_results(i32)/set_max_results(Option<i32>):
required: falseMaximum number of resources to return in the paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falsePagination token to request the next page of resources.
- On success, responds with
ListReportVersionsOutputwith field(s):reports(Vec::<ReportSummary>):List of report resources.
next_token(Option<String>):Pagination token to request the next page of resources.
- On failure, responds with
SdkError<ListReportVersionsError>
Sourceimpl Client
impl Client
Sourcepub fn list_reports(&self) -> ListReportsFluentBuilder
pub fn list_reports(&self) -> ListReportsFluentBuilder
Constructs a fluent builder for the ListReports operation.
This operation supports pagination; See into_paginator().
- The fluent builder is configurable:
max_results(i32)/set_max_results(Option<i32>):
required: falseMaximum number of resources to return in the paginated response.
next_token(impl Into<String>)/set_next_token(Option<String>):
required: falsePagination token to request the next page of resources.
- On success, responds with
ListReportsOutputwith field(s):reports(Option<Vec::<ReportSummary>>):List of report resources.
next_token(Option<String>):Pagination token to request the next page of resources.
- On failure, responds with
SdkError<ListReportsError>
Sourceimpl Client
impl Client
Constructs a fluent builder for the ListTagsForResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the resource.
- On success, responds with
ListTagsForResourceOutputwith field(s):tags(Option<HashMap::<String, String>>):Tags associated with the resource.
- On failure, responds with
SdkError<ListTagsForResourceError>
Sourceimpl Client
impl Client
Sourcepub fn put_account_settings(&self) -> PutAccountSettingsFluentBuilder
pub fn put_account_settings(&self) -> PutAccountSettingsFluentBuilder
Constructs a fluent builder for the PutAccountSettings operation.
- The fluent builder is configurable:
notification_subscription_status(NotificationSubscriptionStatus)/set_notification_subscription_status(Option<NotificationSubscriptionStatus>):
required: falseDesired notification subscription status.
- On success, responds with
PutAccountSettingsOutputwith field(s):account_settings(Option<AccountSettings>):Account settings for the customer.
- On failure, responds with
SdkError<PutAccountSettingsError>
Sourceimpl Client
impl Client
Sourcepub fn put_compliance_inquiry_feedback(
&self,
) -> PutComplianceInquiryFeedbackFluentBuilder
pub fn put_compliance_inquiry_feedback( &self, ) -> PutComplianceInquiryFeedbackFluentBuilder
Constructs a fluent builder for the PutComplianceInquiryFeedback operation.
- The fluent builder is configurable:
compliance_inquiry_id(impl Into<String>)/set_compliance_inquiry_id(Option<String>):
required: trueThe unique identifier for the compliance inquiry.
query_identifier(i32)/set_query_identifier(Option<i32>):
required: falseThe sequential identifier of the query to provide feedback on.
rating(FeedbackRating)/set_rating(Option<FeedbackRating>):
required: trueThe rating for the feedback. Valid values are THUMBS_UP and THUMBS_DOWN.
response_revision_id(i32)/set_response_revision_id(Option<i32>):
required: falseThe response revision ID. Use this value to prevent submitting feedback on a stale response.
reason_codes(FeedbackReasonCode)/set_reason_codes(Option<Vec::<FeedbackReasonCode>>):
required: falseThe reason codes that describe why you rated the response. Valid values are OTHER, PARTIAL_RESPONSE, and IRRELEVANT_RESPONSE.
comment(impl Into<String>)/set_comment(Option<String>):
required: falseAn optional comment for the feedback.
client_token(impl Into<String>)/set_client_token(Option<String>):
required: falseA unique, case-sensitive identifier to ensure that the operation completes no more than one time. If this token matches a previous request, the service ignores the request, but does not return an error.
- On success, responds with
PutComplianceInquiryFeedbackOutputwith field(s):submitted_at(DateTime):The timestamp when the feedback was submitted.
- On failure, responds with
SdkError<PutComplianceInquiryFeedbackError>
Sourceimpl Client
impl Client
Sourcepub fn tag_resource(&self) -> TagResourceFluentBuilder
pub fn tag_resource(&self) -> TagResourceFluentBuilder
Constructs a fluent builder for the TagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the resource.
tags(impl Into<String>, impl Into<String>)/set_tags(Option<HashMap::<String, String>>):
required: trueTags to add to the resource.
- On success, responds with
TagResourceOutput - On failure, responds with
SdkError<TagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn untag_resource(&self) -> UntagResourceFluentBuilder
pub fn untag_resource(&self) -> UntagResourceFluentBuilder
Constructs a fluent builder for the UntagResource operation.
- The fluent builder is configurable:
resource_arn(impl Into<String>)/set_resource_arn(Option<String>):
required: trueThe Amazon Resource Name (ARN) of the resource.
tag_keys(impl Into<String>)/set_tag_keys(Option<Vec::<String>>):
required: trueTag keys to remove from the resource.
- On success, responds with
UntagResourceOutput - On failure, responds with
SdkError<UntagResourceError>
Sourceimpl Client
impl Client
Sourcepub fn from_conf(conf: Config) -> Self
pub fn from_conf(conf: Config) -> Self
Creates a new client from the service Config.
Panics
This method will panic in the following cases:
- Retries or timeouts are enabled without a
sleep_implconfigured. - Identity caching is enabled without a
sleep_implandtime_sourceconfigured. - No
behavior_versionis provided.
The panic message for each of these will have instructions on how to resolve them.
Sourceimpl Client
impl Client
Sourcepub fn new(sdk_config: &SdkConfig) -> Self
pub fn new(sdk_config: &SdkConfig) -> Self
Creates a new client from an SDK Config.
Panics
- This method will panic if the
sdk_configis missing an async sleep implementation. If you experience this panic, set thesleep_implon the Config passed into this function to fix it. - This method will panic if the
sdk_configis missing an HTTP connector. If you experience this panic, set thehttp_connectoron the Config passed into this function to fix it. - This method will panic if no
BehaviorVersionis provided. If you experience this panic, setbehavior_versionon the Config or enable thebehavior-version-latestCargo feature.